"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionParam = void 0;
const assert_1 = __importDefault(require("assert"));
const code_morph_ts_1 = require("@fresha/code-morph-ts");
/**
 * Generates code for a single parameter of a controller action.
 */
class ActionParam {
    context;
    from; // parameter source
    name; // parameter (method argument) name
    schema; // OpenAPI schema
    constructor(context, param) {
        (0, assert_1.default)(param.in === 'path' || param.in === 'query' || param.in === 'body');
        this.context = context;
        this.from = param.in;
        this.name = param.name;
        this.schema = param.schema;
    }
    generateCode(methodDecl) {
        const sourceFile = methodDecl.getSourceFile();
        let decoratorName = '';
        switch (this.from) {
            case 'body':
                decoratorName = 'Body';
                break;
            case 'path':
                decoratorName = 'Param';
                break;
            case 'query':
                decoratorName = 'Query';
                break;
            default:
                assert_1.default.fail(`Unsupported parameter source ${String(this.from)}`);
        }
        (0, code_morph_ts_1.addImportDeclaration)(sourceFile, '@nestjs/common', decoratorName);
        let paramType = 'string';
        let validatorName;
        if (this.schema) {
            switch (this.schema?.type) {
                case null:
                    break;
                case 'boolean':
                    paramType = 'boolean';
                    validatorName = 'ParseBoolPipe';
                    break;
                case 'integer':
                    paramType = 'number';
                    validatorName = 'ParseIntPipe';
                    break;
                case 'number':
                    paramType = 'number';
                    validatorName = 'ParseFloatPipe';
                    break;
                case 'string':
                    break;
                default:
                    if (this.from !== 'body') {
                        assert_1.default.fail(`Unsupported schema type ${this.schema.type}`);
                    }
            }
        }
        if (validatorName) {
            (0, code_morph_ts_1.addImportDeclaration)(methodDecl.getSourceFile(), '@nestjs/common', validatorName);
        }
        const actionParam = methodDecl.addParameter({
            name: this.name,
            type: paramType,
        });
        switch (this.from) {
            case 'body':
                (0, code_morph_ts_1.addDecorator)(actionParam, 'Body', this.name);
                break;
            default: {
                const decorator = (0, code_morph_ts_1.addDecorator)(actionParam, 'Param', this.name);
                if (validatorName) {
                    decorator.addArgument(validatorName);
                }
                break;
            }
        }
    }
}
exports.ActionParam = ActionParam;
//# sourceMappingURL=ActionParam.js.map