"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Generator = void 0;
const assert_1 = __importDefault(require("assert"));
const path_1 = __importDefault(require("path"));
const openapi_codegen_utils_1 = require("@fresha/openapi-codegen-utils");
const Controller_1 = require("./Controller");
const DTO_1 = require("./DTO");
const Module_1 = require("./Module");
class Generator extends openapi_codegen_utils_1.Generator {
    controllers;
    dtos;
    module;
    constructor(context) {
        super(context);
        this.controllers = new Map();
        this.dtos = new Map();
        this.module = new Module_1.Module(this.context);
    }
    get outputPath() {
        return this.context.outputPath;
    }
    get nestApp() {
        return this.context.nestApp;
    }
    getDTO(name) {
        return this.dtos.get(name);
    }
    addDTO(name, schema) {
        (0, assert_1.default)(!this.dtos.has(name));
        const result = new DTO_1.DTO(this.context, name, schema);
        this.dtos.set(name, result);
        return result;
    }
    collectData() {
        for (const [pathUrl, pathItem] of this.context.openapi.paths.pathItems()) {
            this.processPathItem(pathUrl, pathItem);
        }
        for (const controller of this.controllers.values()) {
            this.module.processController(controller);
        }
    }
    processPathItem(pathUrl, pathItem) {
        this.context.logger.info(`Processing '${pathUrl}' item`);
        const className = Controller_1.Controller.makeClassName(pathUrl);
        let controller = this.controllers.get(className);
        if (!controller) {
            controller = new Controller_1.Controller(this.context, path_1.default.join(this.context.outputPath, Controller_1.Controller.makeFileName(pathUrl)), className);
            this.controllers.set(className, controller);
        }
        controller.processPathItem(pathUrl, pathItem);
    }
    generateCode() {
        for (const controller of this.controllers.values()) {
            controller.generateCode();
        }
        this.module.generateCode();
        for (const dto of this.dtos.values()) {
            dto.generateCode();
        }
        if (!this.context.dryRun) {
            this.context.logger.info('Saving changes');
            this.context.project.saveSync();
        }
    }
}
exports.Generator = Generator;
//# sourceMappingURL=Generator.js.map