"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Module = void 0;
const assert_1 = __importDefault(require("assert"));
const path_1 = __importDefault(require("path"));
const code_morph_ts_1 = require("@fresha/code-morph-ts");
const ts_morph_1 = require("ts-morph");
class Module {
    context;
    outputPath;
    controllerImports;
    sourceFile;
    constructor(context) {
        this.context = context;
        this.outputPath = path_1.default.join(this.context.outputPath, `${this.context.nestApp}.module.ts`);
        this.controllerImports = new Map();
        this.sourceFile = this.context.project.getSourceFileOrThrow(this.outputPath);
    }
    processController(controller) {
        const moduleName = `./${path_1.default.basename(controller.outputPath, '.ts')}`;
        (0, assert_1.default)([undefined, moduleName].includes(this.controllerImports.get(controller.className)), `Duplicate import ${controller.className} from module '${moduleName}'`);
        this.controllerImports.set(moduleName, controller.className);
    }
    generateCode() {
        this.context.logger.info(`Generating code for module file ${this.outputPath}`);
        const moduleClassDecl = this.sourceFile.getClasses().at(0);
        (0, assert_1.default)(moduleClassDecl);
        const decoratorArgument = moduleClassDecl
            .getDecorator('Module')
            ?.getNodeProperty('expression')
            .asKindOrThrow(ts_morph_1.SyntaxKind.CallExpression)
            .getNodeProperty('arguments')?.[0]
            .asKindOrThrow(ts_morph_1.SyntaxKind.ObjectLiteralExpression);
        (0, assert_1.default)(decoratorArgument);
        (0, code_morph_ts_1.addImportDeclaration)(this.sourceFile, '@nestjs/core', 'APP_PIPE');
        (0, code_morph_ts_1.addImportDeclaration)(this.sourceFile, '@nestjs/common', 'ValidationPipe');
        const providersProp = decoratorArgument
            .getPropertyOrThrow('providers')
            .asKindOrThrow(ts_morph_1.SyntaxKind.PropertyAssignment)
            .getNodeProperty('initializer')
            .asKindOrThrow(ts_morph_1.SyntaxKind.ArrayLiteralExpression);
        if (!this.sourceFile.getText().includes('provide: APP_PIPE')) {
            providersProp.addElement(`{
        provide: APP_PIPE,
        useClass: ValidationPipe,
      }`);
        }
        for (const [moduleName, controllerName] of this.controllerImports) {
            this.sourceFile.addImportDeclaration({
                moduleSpecifier: moduleName,
                namedImports: [{ name: controllerName }],
            });
        }
        const prop = decoratorArgument
            .getPropertyOrThrow('controllers')
            .asKindOrThrow(ts_morph_1.SyntaxKind.PropertyAssignment)
            .getNodeProperty('initializer')
            .asKindOrThrow(ts_morph_1.SyntaxKind.ArrayLiteralExpression);
        if (prop) {
            for (const controllerName of this.controllerImports.values()) {
                prop.addElement(controllerName);
            }
        }
    }
}
exports.Module = Module;
//# sourceMappingURL=Module.js.map