"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNestJSSubAppPath = void 0;
const assert_1 = __importDefault(require("assert"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
/**
 * For given directory of a NestJS application, and name of a sub-app therein, returns
 * the root folder for that sub-app. The information is read from nest-cli.json file.
 */
const getNestJSSubAppPath = (packageDir, appName) => {
    const filePath = path_1.default.join(packageDir, 'nest-cli.json');
    (0, assert_1.default)(fs_1.default.existsSync(filePath), `${packageDir} does not seem to be a NestJS application`);
    const json = JSON.parse(fs_1.default.readFileSync(filePath, 'utf-8'));
    if (appName) {
        (0, assert_1.default)(json.projects);
        const result = json.projects[appName]?.sourceRoot;
        (0, assert_1.default)(!!result, `Cannot determine source root of "${appName}" app in ${packageDir}/nest-cli.json`);
        return path_1.default.join(packageDir, result);
    }
    const result = json.sourceRoot;
    (0, assert_1.default)(!!result, `Cannot determine source root in ${packageDir}/nest-cli.json`);
    return path_1.default.join(packageDir, result);
};
exports.getNestJSSubAppPath = getNestJSSubAppPath;
//# sourceMappingURL=utils.js.map